@@ -12,46 +12,49 @@ Jim Turner
 
 use String::PictureFormat;
 
-$_ = fmt('@"...-..-...."', 123456789);
-print "-formatted=$_=\n";           #RETURNS "123-45-6789".
+print "-formatted=".fmt('@"...-..-...."', 123456789)."=\n";
+#RETURNS "123-45-6789".
 
-$_ = unfmt('@"...-..-...."', '123-45-6789');
-print "-unformatted=$_=\n";         #RETURNS "123456789".
+print "-unformatted=".unfmt('@"...-..-...."', '123-45-6789')."=\n";
+#RETURNS "123456789".
 
-$_ = fmt('@$,12.2>', 123456789);
-print "-formatted=$_= \n";          #RETURNS "    $123,456,789.00".
+print "-formatted=".fmt('@$,12.2>', 123456789)."= \n";
+#RETURNS "    $123,456,789.00".
 
-$_ = fmtsiz('@$,12.2>');
-print "-format size=$_= \n";        #RETURNS 18.
+print "-format size=".fmtsiz('@$,12.2>')."= \n";
+#RETURNS 18.
 
-$_ = fmt('@$,12.2> CR', -123456789);  
-print "-formatted=$_=\n";           #RETURNS "    $123,456,789.00 CR".
+print "-formatted=".fmt('@$,12.2> CR', -123456789)."=\n";
+#RETURNS "    $123,456,789.00 CR".
 
-$_ = fmt('@$,12.2> CR', 123456789);  
-print "-formatted=$_=\n";           #RETURNS "    $123,456,789.00   ".
+print "-formatted=".fmt('@$,12.2> CR', 123456789)."=\n";
+#RETURNS "    $123,456,789.00   ".
 
-$_ = fmt('@$,12.2>', -123456789);  
-print "-formatted=$_=\n";           #RETURNS "   $-123,456,789.00".
+print "-formatted=".fmt('@$,12.2>', -123456789)."=\n";
+#RETURNS "   $-123,456,789.00".
 
-$_ = fmt('@-$,12.2>', -123456789);  
-print "-formatted=$_=\n";           #RETURNS "    -$123,456,789.00".
+print "-formatted=".fmt('@-$,12.2>', -123456789)."=\n";
+#RETURNS "    -$123,456,789.00".
 
-$_ = fmt('@$(,12.2>)', -123456789);  
-print "-formatted=$_=\n";           #RETURNS "    $(123,456,789.00)".
+print "-formatted=".fmt('@$(,12.2>)', -123456789)."=\n";
+#RETURNS "    $(123,456,789.00)".
 
 $_ = fmt('=16<', 'Now is the time for all good men to come to the aid of their country');
-print "-s=".join('|',@{$s})."=\n";  #RETURNS "Now is the time   |for all good men  |to come to the aid|of their country  =".
+print "-formatted=".join('|',@{$_})."=\n";
+#RETURNS "Now is the time   |for all good men  |to come to the aid|of their country  =".
 
 sub foo {
 	(my $data = shift) =~ tr/a-z/A-Z/;
 	return $data;
 }
-...
-$_ = fmt('@foo()', 'Now is the time for all');
-print "-formatted=$_=\n";           #RETURNS "NOW IS THE TIME FOR ALL"
 
-$_ = fmt('@tr/aeiou/AEIOU/', 'Now is the time for all');
-print "-formatted=$_=\n";           #RETURNS "NOw Is thE tImE fOr All"
+print "-formatted=".fmt('@foo()', 'Now is the time for all')."=\n";
+#RETURNS "NOW IS THE TIME FOR ALL"
+
+print "-formatted=".fmt('@tr/aeiou/AEIOU/', 'Now is the time for all')."=\n";
+#RETURNS "NOw Is thE tImE fOr All"
+
+exit(0);
 
 =head1 DESCRIPTION
 
@@ -510,7 +513,7 @@ package String::PictureFormat;
 use strict;
 #use warnings;
 use vars qw(@ISA @EXPORT $VERSION);
-$VERSION = '1.1';
+$VERSION = '1.11';
 
 use Time::Local;
 
@@ -518,12 +521,11 @@ require Exporter;
 
 my $haveTime2fmtstr = 0;
 my $haveFmtstr2time = 0;
-#eval 'require "to_char.pl"; $haveTime2fmtstr = 1; 1';
 
 @ISA = qw(Exporter);
 @EXPORT = qw(fmt fmtsiz fmtjust fmtsuffix unfmt);
 
-sub fmt {
+sub fmt {       #FORMAT INPUT DATA STRING BASED ON "PICTURE" STRING:
 	my $pic = shift;
 	my $v = shift;
 	my $ops = shift;
@@ -542,8 +544,8 @@ sub fmt {
 			my $cnt = 0;                #EXAMPLE: fmt("@\"...-..-.+\";suffix", '123456789'); FORMATS AN SSN:
 			my $frompic = '';
 			my $graball = 0;
-			my $charsHandled = 0;   #NO. OF CHARS IN THE INPUT STRING THAT CAN BE OUTPUT.
-			$pic =~ s/\\\+/\x02/go;
+			my $charsHandled = 0;       #NO. OF CHARS IN THE INPUT STRING THAT CAN BE OUTPUT.
+			$pic =~ s/\\\+/\x02/go;     #PROTECT ESCAPED METACHARACTERS.
 			$pic =~ s/\\\./\x03/go;
 			$pic =~ s/\\\^/\x04/go;
 			my $t = $pic;
@@ -584,7 +586,7 @@ sub fmt {
 			}
 			my $v0 = $v;
 			eval $evalstr;
-			$v =~ s/\x04/\^/go;
+			$v =~ s/\x04/\^/go;   #UNPROTECT METACHARACTERS.
 			$v =~ s/\x03/\./go;
 			$v =~ s/\x02/\+/go;
 			if ((length($v0) > $charsHandled || ($leni > 0 && length($v) > $leni)) && $ops->{'-truncate'} !~ /no/io) {
@@ -616,7 +618,7 @@ sub fmt {
 			$perltime ||= ($v =~ /^\d{9,11}$/o) ? $v : 0;
 			unless ($perltime) {  #WE HAVE A DATE STRING, IE. yyyy-dd-mm, etc. THAT CHKDATE CAN HANDLE:
 				($t, $perltime) = _chkdate($v);
-				unless ($t || $perltime) {
+				unless ($t || $perltime) {       #chkdate() DID NOT RECOGNIZE THE INPUT STRING, SO PUNT.
 					$leni ||= $fixedLeni || length($pic);
 					$v = $errchar x $leni;
 					return wantarray ? ($v, $leni, $justify) : $v;
@@ -627,7 +629,7 @@ sub fmt {
 				}
 			}
 			$v = $perltime  if ($perltime);
-			if ($perltime) {   #WE HAVE A PERL "TIME":
+			if ($perltime) {   #WE HAVE A PERL "TIME" (EITHER GIVEN OR RETURNED BY chkdate():
 				if ($haveTime2fmtstr) {       #WE ALSO HAVE Time2fmtstr!:
 					$t = time2str($v, $pic);
 					$leni ||= $fixedLeni || length($t);
@@ -645,7 +647,7 @@ sub fmt {
 							. ' ' . sprintf('%2.2d',$tv[2]) . sprintf('%2.2d',$tv[1]) . sprintf('%2.2d',$tv[0]);
 				}
 			}
-			if ($t =~ /^\d{8}(?: \d{4,6})?$/o) {   #WE HAVE A STRING WE CAN TRY TO CONVERT MANUALLY:
+			if ($t =~ /^\d{8}(?: \d{4,6})?$/o) {    #WE HAVE A DATE/TIME STRING WE CAN (TRY) TO CONVERT MANUALLY:
 				$pic =~ s/yyyy/substr($t,0,4)/ie;
 				$pic =~ s/yy/substr($t,2,4)/ie;
 				$pic =~ s/mm/substr($t,4,2)/ie;
@@ -661,7 +663,7 @@ sub fmt {
 				}
 				$v .= $suffix  unless ($ops->{'-suffix'} =~ /no/io);
 				return wantarray ? ($v, $leni, $justify) : $v;
-			} else {
+			} else {     #WE GOT NOTHING WE CAN WORK WITH, SO PUNT!
 				$leni ||= $fixedLeni || length($pic);
 				$v = $errchar x $leni;
 				return wantarray ? ($v, $leni, $justify) : $v;
@@ -679,11 +681,11 @@ sub fmt {
 			return wantarray ? ($v, $leni, $justify) : $v;
 		} elsif ($pic =~ /^[a-zA-Z_]+/o) {     #USER-SUPPLIED FUNCTION (@foo('*'))
 			$suffix = ($pic =~ s/\)([^\)]*)$/\)/) ? $1 : '';
-			$pic =~ s/\\\*/\x02/og;
+			$pic =~ s/\\\*/\x02/og;   #PROTECT ESCAPED METACHARACTERS:
 			$pic =~ s/\\\#/\x03/og;
 			$pic =~ s/\\\(/\x04/og;
 			$pic =~ s/\\\)/\x05/og;
-			$pic =~ s/\(\s*\)/\(\*\,\#\)/o;
+			$pic =~ s/\(\s*\)/\(\*\,\#\)/o;   #WE ALWAYS PASS IT THE INPUT STRING AND LENGTH WE'RE EXPECTING (OR ZERO)
 			if ($v =~ /^\d+$/o)
 			{
 				$pic =~ s/\*/$v/g;
@@ -692,7 +694,7 @@ sub fmt {
 			{
 				$pic =~ s/\*/\'$v\'/g;
 			}
-			$pic =~ s/\#/$leni/g;
+			$pic =~ s/\#/$leni/g;    #UNPROTECT ESCAPED METACHARACTERS:
 			$pic =~ s/\x05/\)/og;
 			$pic =~ s/\x04/\(/og;
 			$pic =~ s/\x03/\#/og;
@@ -707,10 +709,9 @@ sub fmt {
 			}
 			$t .= $suffix  unless ($ops->{'-suffix'} =~ /no/io);
 			return wantarray ? ($t, $leni, $justify) : $t;
-		} else {                               #REGULAR STUFF, IE. @12>.>>)
+		} else {                               #REGULAR JUSTIFY STUFF, IE. @12>.>>)
 			my $leniSpecified = $leni;
-			if ($pic =~ /^\*(.*)$/)
-			{
+			if ($pic =~ /^\*(.*)$/)	{   #WE'RE JUST AN ASTERISK, JUST RETURN THE INPUT STRING UNCHANGED:
 				$suffix = $1;
 				if ($leni && length($v) > $leni && $ops->{'-truncate'} !~ /no/io) {
 					$v = ($ops->{'-truncate'} =~ /er/io) ? $errchar x $leni : substr($v, 0, $leni);
@@ -729,20 +730,20 @@ sub fmt {
 					$float .= $special; #OTHERS, IE. (@$) ARE FLOATERS:
 				}
 			}
-			my $switchFloat = ($float =~ /\+\$/o) ? 1 : 0;
+			my $switchFloat = ($float =~ /\+\$/o) ? 1 : 0;   #SPECIAL CASE: USER WANTS SIGN *BEFORE* "$"
 			if ($float =~ /\(/o)   #ONLY KEEP FLOATING "(" IF SUFFIX STARTS WITH A ")"!
 			{
 				$float =~ s/\(//o  unless ($suffix =~ /^\)/o);
 			}
 			if ($v < 0)
 			{
-				$float =~ s/\+//go;   #REMOVE FLOATING "+" IF VALUE IS NEGATIVE.
+				$float =~ s/\+//go  unless ($ops->{'-nonnumeric'});   #REMOVE FLOATING "+" IF VALUE IS NEGATIVE.
 				$leni = 1 + length($float)  unless ($fixedLeni || $leniSpecified);  #COUNT FLOATING CHARS IN FIELD SIZE:
 			}
 			else
 			{
 				$leni = 1 + length($float)  unless ($fixedLeni || $leniSpecified);  #COUNT FLOATING CHARS IN FIELD SIZE:
-				$float =~ s/\-//o;
+				$float =~ s/\-//o  unless ($ops->{'-nonnumeric'});
 				$leni++  if (!($fixedLeni || $leniSpecified) && $float =~ s/\(//o);   #REMOVE FLOATING "(..)" IF VALUE IS NOT NEGATIVE.
 			}
 			$pic =~ s/(\d+)[<|>]?([\.\^]?)(\d*)([<|>])/
@@ -751,11 +752,12 @@ sub fmt {
 					my $exp = ($three x $one);
 					$exp .= $dec . ($three x $two)  if ($two > 0);
 					$exp
-			/e;                   #CONVERT STUFF LIKE "@12.2>" TO "@12>.2>".
+			/e;        #CONVERT STUFF LIKE "@12.2>" TO "@<<<<<<<<<<<<.<<".
 			#DEFAULT JUSTIFY:  RIGHT IF COMMATIZING(NUMBER) OR FLOATING$ OR PICTURE CONTAINS DECIMAL;
 			#OTHERWISE, DEFAULT IS LEFT.
-			$justify ||= ($commatize || $float =~ /\$/o || $pic =~ /[\.\,\^\$]/o) ? '>' : '<';
-			#CALCULATE FIELD SIZE BASED ON NO. OF "<, >, |" AND PRECEEDING REPEATER DIGITS:
+			$justify ||= (!($ops->{'-nonnumeric'})
+					&& ($commatize || $float =~ /\$/o || $pic =~ /[\.\,\^\$]/o)) ? '>' : '<';
+			#CALCULATE FIELD SIZE BASED ON NO. OF "<, >, |" AND PRECEEDING REPEATER DIGITS (UNLESS PRE-SPECIFIED BY "@##:":
 			unless ($fixedLeni || $leniSpecified)
 			{
 				$leni += length($pic); # && $pic =~ /([<|>\.]+)/o);
@@ -764,17 +766,17 @@ sub fmt {
 			my $decLeni = 0;
 			my $wholeLeni = $leni;
 			my $decJustify = $justify;
-			if ($decPic && !$ops->{'-nonnumeric'}) {   #PICTURE CONTAINS A DECIMAL, CALCULATE SEPARATE LENGTHS, ETC.
+			if ($decPic && !$ops->{'-nonnumeric'}) {   #PICTURE CONTAINS A DECIMAL (REAL OR IMPLIED), CALCULATE SEPARATE LENGTHS, ETC.
 				$decLeni = 0;
 				$t = $decPic;
 				$decLeni += length($1)  while ($t =~ s/([\<\|\>\.\^\,\$]+)//o);
 				$decLeni += $1 - 1  while ($t =~ s/(\d+)//o);
-				$decJustify = $1  if ($decPic =~ /([\<\|\>])$/o);
+				$decJustify = $1  if ($decPic =~ /([\<\|\>])$/o);  #WE DON'T "JUSTIFY" DECIMALS, BUT USE FOR DETERMING TRUNCATION, IF NEEDED.
 				$wholeLeni = $leni - ($decLeni + 1);
 				if ($pic !~ /\./o && $v !~ /\./) {  #WE HAVE AN "IMPLIED DECIMAL POINT!
 					$v = sprintf("%.${decLeni}f", $v / (10**$decLeni))  if ($v =~ /^[\+\-\d\. ]+$/o);
 				}
-				my ($whole, $decimal) = split(/\./o, $v);   #SPLIT THE VALUE TOO:
+				my ($whole, $decimal) = split(/\./o, $v);   #SPLIT THE VALUE IN TWO:
 				unless ($float =~ /\+/o) {
 					$whole =~ s/^-//o  if ($v >= 0 || $suffix =~ /^[\_ ]*CR\s*$/io)
 				}
@@ -784,14 +786,14 @@ sub fmt {
 				}
 				$t = $whole . '.' . $decimal;
 				if ($decJustify eq '>') {   #CHOP RIGHT-MOST DECIMAL PLACES AS NEEDED TO FIT IFF DECIMAL PART IS "RIGHT-JUSTIFIED"
-					while (length($t) > $leni && $t =~ /\./o) {  #NOTE:WE DON'T "JUSTIFY" THE DECIMAL PART!
+					while (length($t) > $leni && $t =~ /\./o) {   #NOTE:WE DON'T "JUSTIFY" THE DECIMAL PART!
 						chop $t;
 						$decLeni--;
 					}
 				}
 				$decLeni = 0  if ($decLeni < 0);
 				$pic = '%.'.$decLeni.'f';   #BUILD SPRINTF TO ADD/ROUND DECIMAL PLACES.
-				$t = sprintf($pic, $v);     #JUST THE # W/PROPER # OF DECIMAL PLACES.
+				$t = sprintf($pic, $v);     #JUST THE NUMBER W/PROPER # OF DECIMAL PLACES.
 			} else {
 				$t = $v;
 				my $l = length($v);
@@ -807,11 +809,11 @@ sub fmt {
 			}
 			unless ($ops->{'-nonnumeric'})
 			{
-				if ($v >= 0)   #SPECIAL SUFFIX "CR" OR " CR":  REMOVE IF VALUE >= 0:
+				if ($v >= 0)   #SPECIAL ACCOUNTING SUFFIX "CR" OR " CR":  REMOVE IF VALUE >= 0:
 				{
 					$suffix =~ s/^([\_ ]*)CR\s*$/' 'x(length($1)+2)/ei;
 				}
-				else     #INCLUDE SPECIAL SUFFIX "CR" OR "_CR" IF VALUE < 0 FOR ACCOUNTING:
+				else           #INCLUDE SPECIAL SUFFIX "CR" OR " CR" IF VALUE < 0 FOR ACCOUNTING:
 				{
 					$t =~ s/\-//o  if ($suffix =~ s/^([\_ ]*)(CR\s*)$/(' 'x(length($1))).$2/ei);
 				}
@@ -827,22 +829,22 @@ sub fmt {
 				}
 			}
 			$t =~ s/^[^ \d\<\|\>\.]([ \d\.\-\+]+)$/\($1/  if ($l == $leni && $v < 0 && $float =~ s/\(//o && !$ops->{'-nonnumeric'});
-			if ($commatize) {      #ADD COMMAS TO LARGE NUMBERS, IF WILL FIT:
+			if ($commatize) {      #ADD COMMAS TO LARGE NUMBERS EVERY PLACES, IF WILL FIT:
 				$l = length($t);
 				if ($decJustify eq '>') {
-					while ($l > $leni && $t =~ /\./o) {
+					while ($l > $leni && $t =~ /\./o) {   #CHOP OFF LOW-ORDER DECIMAL PLACES AS NEEDED TO FIT:
 						chop $t;
 					}
 				}
-				while ((!$leniSpecified || $l < $leni) && $t =~ s/(\d)(\d\d\d)\b/$1,$2/) {
+				while ((!$leniSpecified || $l < $leni) && $t =~ s/(\d)(\d\d\d)\b/$1,$2/) {  #ADD COMMAS AS NEEDED:
 					$l = length($t);
 					$leni++  unless ($fixedLeni || $leniSpecified);
 				}
 			}
 			$t =~ s/\$\-/\-\$/o  if ($switchFloat);
-			if ($ops->{'-truncate'} =~ /er/io && length($t) > $leni) {
+			if ($ops->{'-truncate'} =~ /er/io && length($t) > $leni) {  #WON'T FIT AND USER WANTS ERROR IF SO:
 				$v = $errchar x $leni;
-			} elsif ($ops->{'-truncate'} !~ /no/io || length($t) <= $leni) {
+			} elsif ($ops->{'-truncate'} !~ /no/io || length($t) <= $leni) {  #USER WANTS TRUNCATED, IF WON'T FIT:
 				$leni--  if (!($fixedLeni || $leniSpecified) && $float =~ /\(/o);
 				if ($justify eq '|') {    #JUSTIFY:
 					my $j = int(($leni - $l) / 2);
@@ -853,7 +855,7 @@ sub fmt {
 				} else {
 					$v = sprintf("%${leni}s", $t);
 				}
-			} else {
+			} else {   #USER WANTS EVERYTHING, EVEN IF WON'T FIT:
 				$leni--  if (!($fixedLeni || $leniSpecified) && $float =~ /\(/o);
 				$v = $t;
 			}
@@ -968,7 +970,7 @@ sub fmt {
 			$v = sprintf("%.${decimal}f", $v);
 		}
 		my $l;
-		if ($commatize) {
+		if ($commatize) {   #USER WANTS COMMAS ADDED TO LARGE NUMBERS:
 			unless ($fixedLeni) {
 				$leni++  if ($pic =~ /^\%(\d+)/o);
 			}
@@ -996,7 +998,7 @@ sub fmt {
 	}
 }
 
-sub unfmt {
+sub unfmt {       #UNFORMAT INPUT DATA STRING BASED ON "PICTURE" STRING (AS IF PREVIOUSLY FORMATTED BY SAME STRING:
 	my $pic = shift;
 	my $v = shift;
 	my $ops = shift;
@@ -1027,7 +1029,7 @@ sub unfmt {
 			$r0 = "\Q$r0\E";
 			$r0 =~ s/P(\d+)/$QS[$1]/gs;
 			$i = 1;
-			$i++ while ($r =~ s/\(.+?\)/\$$i/s);
+			$i++  while ($r =~ s/\(.+?\)/\$$i/s);
 			$r =~ s/\^/ /gso;
 			$r =~ s/[^\$\d ]//gso;
 			my $evalstr = "\$v =~ s\"$r0\"$r\"";
@@ -1074,7 +1076,7 @@ sub unfmt {
 				$t = ($ops->{'-truncate'} =~ /er/io) ? $errchar x $leni : substr($t, 0, $leni);
 			}
 			return wantarray ? ($t, $leni, $justify) : $t;
-		} elsif ($pic =~ m#^(?:s|tr)(\W)#) { #REGEX SUBSTITUTION (@s/foo/bar/)  #NOTE:  UNFMT=FMT!!!
+		} elsif ($pic =~ m#^(?:s|tr)(\W)#) { #REGEX SUBSTITUTION (@s/foo/bar/)  #NOTE:  unfmt() SAME AS fmt()!
 			my $regexDelimiter = $2;
 			$v =~ s/$1$//  if ($pic =~ s#\Q$regexDelimiter\E(.*)$##);
 			my $evalstr = '$v =~ '.$pic;
@@ -1083,9 +1085,9 @@ sub unfmt {
 				$v = ($ops->{'-truncate'} =~ /er/io) ? $errchar x $leni : substr($v, 0, $leni);
 			}
 			return wantarray ? ($v, $leni, $justify) : $v;
-		} elsif ($pic =~ /^[a-zA-Z_]+/o) {     #USER-SUPPLIED FUNCTION (@foo('*'))  #NOTE:  UNFMT=FMT!!!
+		} elsif ($pic =~ /^[a-zA-Z_]+/o) {     #USER-SUPPLIED FUNCTION (@foo('*'))  #NOTE:  unfmt() SAME AS fmt()!
 			$v =~ s/$1$//  if ($pic =~ s#\Q\;\E(.*)$##);
-			$pic =~ s/\\\*/\x02/og;
+			$pic =~ s/\\\*/\x02/og;  #PROTECT ESCAPED METACHARACTERS:
 			$pic =~ s/\\\*/\x02/og;
 			$pic =~ s/\\\#/\x03/og;
 			if ($v =~ /^\d+$/o)
@@ -1096,7 +1098,7 @@ sub unfmt {
 			{
 				$pic =~ s/\*/\'$v\'/g;
 			}
-			$pic =~ s/\#/$leni/g;
+			$pic =~ s/\#/$leni/g;   #UNPROTECT ESCAPED METACHARACTERS:
 			$pic =~ s/\x03/\#/og;
 			$pic =~ s/\x02/\*/og;
 			$pic = 'main::' . $pic  unless ($pic =~ /^\w+\:\:/o);
@@ -1109,9 +1111,8 @@ sub unfmt {
 				$v = ($ops->{'-truncate'} =~ /er/io) ? $errchar x $leni : substr($v, 0, $leni);
 			}
 			return wantarray ? ($t, $leni, $justify) : $t;
-		} else {                               #REGULAR STUFF, IE. @12>.>>)
-			if ($pic =~ /^\*(.*)$/)
-			{
+		} else {                               #REGULAR JUSTIFY STUFF, IE. @12>.>>)
+			if ($pic =~ /^\*(.*)$/) {          #WE'RE JUST AN ASTERISK, JUST RETURN THE INPUT STRING UNCHANGED:
 				$suffix = $1;
 				if ($leni && length($v) > $leni && $ops->{'-truncate'} !~ /no/io) {
 					$v = ($ops->{'-truncate'} =~ /er/io) ? $errchar x $leni : substr($v, 0, $leni);
@@ -1149,7 +1150,7 @@ sub unfmt {
 					my $exp = ($three x $one);
 					$exp .= $dec . ($three x $two)  if ($two > 0);
 					$exp
-			/e;                   #CONVERT STUFF LIKE "@12.2>" TO "@12>.2>".
+			/e;        #CONVERT STUFF LIKE "@12.2>" TO "@>>>>>>>>>>>>.>>>".
 			my $justify = ($pic =~ /^.*?([<|>])/o) ? $1 : '';
 			my $decJustify;
 			if ($pic =~ /^([<|>]+)[\.\^]([<|>]+)/o) {
@@ -1281,7 +1282,7 @@ sub unfmt {
 	}
 }
 
-sub fmtsiz {
+sub fmtsiz {   #RETURN THE "SIZE" STRING THE "PICTURE STRING" ARGUMENT REPRESENTS (NOT THE LENGTH ITSELF) - CAN BE ZERO IF VARIABLE:
 	my $pic = shift;
 	my $v = shift;
 	my $leni;
@@ -1327,7 +1328,7 @@ sub fmtsiz {
 					my $exp = ($three x $one);
 					$exp .= $dec . ($three x $two)  if ($two > 0);
 					$exp
-			/e;                   #CONVERT STUFF LIKE "@12.2>" TO "@12>.2>".
+			/e;        #CONVERT STUFF LIKE "@12.2>" TO "@>>>>>>>>>>>>.>>".
 			$t = $pic;
 			#CALCULATE FIELD SIZE BASED ON NO. OF "<, >, |" AND PRECEEDING REPEATER DIGITS:
 			$leni += length($1)  while ($t =~ s/([\<\|\>\.\^\,\$]+)//o);
@@ -1364,23 +1365,23 @@ sub fmtsiz {
 	}
 }
 
-sub fmtjust {
+sub fmtjust {   #RETURN THE "JUSTIFICATION" DIRECTION THE "PICTURE STRING" REPRESENTS ("<", ">", "|", OR "", IN INDETERMINATE)
 	my $pic = shift;
 	my $v = shift;
 
 	my $leni;
 	my $suffix;
-	if ($pic =~ s/^\@//o) {               #@-strings:
+	if ($pic =~ s/^\@//o) {                  #@-strings:
 		$pic =~ s/(\d+)\://o;
-		if ($pic =~ s/^[\'\"\/\`]//o) {         #PICTURE LITERAL   (@'foo'
+		if ($pic =~ s/^[\'\"\/\`]//o) {      #PICTURE LITERAL   (@'foo'
 			return '<';
 		} elsif ($pic =~ s#^\^##o) {         #DATE-CONVERSION
 			return '<';
-		} elsif ($pic =~ m#^(?:s|tr)\W#o) {          #REGEX SUBSTITUTION (@s/foo/bar/)
+		} elsif ($pic =~ m#^(?:s|tr)\W#o) {  #REGEX SUBSTITUTION (@s/foo/bar/)
 			return '<';
-		} elsif ($pic =~ /^[a-zA-Z_]+/o) {     #USER-SUPPLIED FUNCTION (@foo('*'))
+		} elsif ($pic =~ /^[a-zA-Z_]+/o) {   #USER-SUPPLIED FUNCTION (@foo('*'))
 			return '<';
-		} else {                               #REGULAR STUFF, IE. @12>.>>)
+		} else {                             #REGULAR STUFF, IE. @12>.>>)
 			return '<'  if ($pic =~ /^\*(.*)$/);
 			$suffix = $1  if ($pic =~ s/([^\<\|\>\.\^]+)$//o);
 			my ($special, $float, $t);
@@ -1419,7 +1420,7 @@ sub fmtjust {
 		$wrapchar = 'w'  if ($pic =~ /w/o);         #LITTLE w=WRAP AT CHARACTER:
 		$justify = $1  if ($pic =~ /^.*([<|>])/o);  #BIG W=WRAP AT WORD BOUNDARIES (Text::Wrap):
 		return $justify;
-	} elsif ($pic =~ s/^\%//o) {         #C-PRINTF FORMAT STRINGS (%-STRINGS) (AS-IS, "%" NOT INCLUDED IN FIELD SIZE):
+	} elsif ($pic =~ s/^\%//o) {    #C-PRINTF FORMAT STRINGS (%-STRINGS) (AS-IS, "%" NOT INCLUDED IN FIELD SIZE):
 		my $float = ($pic =~ s/^\$//o) ? '$' : '';  #EXCEPTION:  FLOATING $, COMMA(COMMATIZE) ALLOWED AFTER "%":
 		my $commatize = ($pic =~ s/^\,//o) ? 1 : 0;    #IE:  "%$,-14.2f":  FIELD SIZE=16!
 		$suffix = ($pic =~ s/^(\-?[\d\.]+\w)(.*$)/$1/o) ? $2 : '';
@@ -1432,32 +1433,32 @@ sub fmtjust {
 	return '<';
 }
 
-sub fmtsuffix {
-	my $pic = shift;
+sub fmtsuffix {       #RETURN JUST THE SUFFIX PART, IF ANY, IN THE PICTURE STRING (OR "") IF NONE.
+	my $pic = shift;  #ANY CHARACTERS AFTER THE "PICTURE STRING" METACHARACTERS IS TREATED AS THE "SUFFIX"
 	my $v = shift;
 	my $ops = shift;
 
 	my $leni;
 	my $suffix = '';
-	if ($pic =~ s/^\@//o) {               #@-strings:
+	if ($pic =~ s/^\@//o) {            #@-strings:
 		$pic =~ s/(\d+)\://o;
-		if ($pic =~ s/^([\'\"\/\`])//o) {         #PICTURE LITERAL   (@'foo'
-			my $regexDelimiter = $1;         #REPLACE EACH DOT WITH NEXT CHAR. SKIP ONES CORRESPONDING WITH "^", ALL OTHER CHARS ARE LITERAL.
+		if ($pic =~ s/^([\'\"\/\`])//o) {  #PICTURE LITERAL   (@'foo'
+			my $regexDelimiter = $1;       #REPLACE EACH DOT WITH NEXT CHAR. SKIP ONES CORRESPONDING WITH "^", ALL OTHER CHARS ARE LITERAL.
 			$suffix = $1  if ($pic =~ s#\Q$regexDelimiter\E(.*)$##);
 			return $suffix;
-		} elsif ($pic =~ s#^\^##o) {         #DATE-CONVERSION
+		} elsif ($pic =~ s#^\^##o) {  #DATE-CONVERSION
 			$pic =~ s/\\\^/\x04/go;   #PROTECT ESCAPED "^" IN FORMAT STRING!
 			$suffix = ($pic =~ s#\^([^\^]*)$##) ? $1 : '';
 			$suffix =~ s/\x04/\^/go;  #UNPROTECT ESCAPED "^" IN FORMAT STRING!
 			return $suffix;
-		} elsif ($pic =~ m#^(?:s|tr)(\W)#) {          #REGEX SUBSTITUTION (@s/foo/bar/)
+		} elsif ($pic =~ m#^(?:s|tr)(\W)#) {   #REGEX SUBSTITUTION (@s/foo/bar/)
 			my $regexDelimiter = $1;
 			$suffix = $1  if ($pic =~ s#([^$regexDelimiter]+)$##);
 			return $suffix;
 		} elsif ($pic =~ /^[a-zA-Z_]+/o) {     #USER-SUPPLIED FUNCTION (@foo('*'))
 			$suffix = $1  if ($pic =~ s/\)([^\)]*)$/\)/o);
 			return $suffix;
-		} else {                               #REGULAR STUFF, IE. @12>.>>)
+		} else {                               #REGULAR JUSTIFY STUFF, IE. @12>.>>)
 			return $1  if ($pic =~ /^\*(.*)$/);
 			$suffix = $1  if ($pic =~ s/([^<|>.]+)$//o);
 			return $suffix;
@@ -1467,7 +1468,7 @@ sub fmtsuffix {
 		my $j = 1;
 		$suffix = $1  if ($pic =~ s/([^wW<|>\d]+)$//o);
 		return $suffix;
-	} elsif ($pic =~ s/^\%//o) {         #C-PRINTF FORMAT STRINGS (%-STRINGS) (AS-IS, "%" NOT INCLUDED IN FIELD SIZE):
+	} elsif ($pic =~ s/^\%//o) {    #C-PRINTF FORMAT STRINGS (%-STRINGS) (AS-IS, "%" NOT INCLUDED IN FIELD SIZE):
 		$pic =~ s/^\$//o;
 		$pic =~ s/^\,//o;
 		$suffix = ($pic =~ s/^(\-?[\d\.]+\w)(.*)$/$1/o) ? $2 : '';
@@ -1477,7 +1478,7 @@ sub fmtsuffix {
 	}
 }
 
-sub _chkdate#    #CONVER USER-ENTERED DATES TO "yyyymmdd".
+sub _chkdate#    #(INTERNAL) TRY TO PARSE OUT AND CONVERT USER-ENTERED DATE/TIME STRINGS TO "yyyymmdd [hhmm[ss]]".
 {
 	#### Y2K COMPLIANT UNTIL 2080.
 	#### NOTE:  6-DIGIT DATES W/SEPARATORS ARE HANDLED AS mmddyy!
@@ -1487,50 +1488,50 @@ sub _chkdate#    #CONVER USER-ENTERED DATES TO "yyyymmdd".
 	my ($res);
 	return wantarray ? ($dt,0) : $dt  unless ($dt =~ /\S/o);
 	$dt = substr($dt,0,8) . ' ' . substr($dt,8)  if ($dt =~ /\d{9,14}\D*$/o);
-	if ($dt =~ s#(\d+)[\/\-\.](\d+)[\/\-\.](\d+)##o)
+	if ($dt =~ s#(\d+)[\/\-\.](\d+)[\/\-\.](\d+)##o)   #DATE PART HAS SEPARATORS (ie. mm/dd/yyyy):
 	{
 		my $x;
-		if ($1 < 1000 && $3 < 1000)    #user entered:  "mm/dd/yy"|"mm-dd-yy"|"mm.dd.yy"
+		if ($1 < 1000 && $3 < 1000)    #2-DIGIT YEAR:  "mm/dd/yy"|"mm-dd-yy"|"mm.dd.yy" (MAKE ASSUMPTIONS):
 		{
-			my $century = ($3 < 80) ? 20 : 19;  #Y2K:80-99=19##; 00-79=20##!
+			my $century = ($3 < 80) ? 20 : 19;   #Y2K:80-99=19##; 00-79=20##!
 			$x = sprintf '%-2.2d%-2.2d%-2.2d%-2.2d',$century,$3,$1,$2
 		}
-		elsif ($1 > 1000)  #user entered:  "yyyy/mm/dd"|"yyyy-mm-dd"|"yyyy.mm.dd"
+		elsif ($1 > 1000)  #4-DIGIT YEAR:  "yyyy/mm/dd"|"yyyy-mm-dd"|"yyyy.mm.dd"
 		{
 			$x = sprintf '%-2.2d%-2.2d%-2.2d',$1,$2,$3;
 		}
-		else              #user entered:  "mm/dd/yyyy"|"mm-dd-yyyy"|"mm.dd.yyyy"
+		else              #4-DIGIT YEAR, ASSUME:  "mm/dd/yyyy"|"mm-dd-yyyy"|"mm.dd.yyyy"
 		{
 			$x = sprintf '%-2.2d%-2.2d%-2.2d',$3,$1,$2;
 		}
 		my $then = 0;
-		if ($dt =~ s#^\D+(\d\d?)\:?(\d\d?)##o)
+		if ($dt =~ s#^\D+(\d\d?)\:?(\d\d?)##o)   #STRING HAS A "TIME" PART:
 		{
 			$x .= ' ' . sprintf '%-2.2d%-2.2d',$1,$2;
 			$x .= ($dt =~ s#\:?(\d\d?)##o) ? sprintf('%-2.2d',$1) : '00';
-			if ($dt =~ m#(\s*[ap]m?)#i)
+			if ($dt =~ m#(\s*[ap]m?)#i)   #STRING HAS AM/PM SUFFIX (12-HOUR TIME)
 			{
 				my $indicator = $1;
 				my $hr = $1  if ($x =~ /\d (\d\d)/);
-				if ($indicator =~ /a/i && $hr == 12)
+				if ($indicator =~ /a/i && $hr == 12)     #12 AM BECOMES 00:
 				{
 					$x =~ s/(\d) (\d\d)/$1 . ' 00'/e;
 				}
-				elsif ($indicator =~ /p/i && $hr != 12)
+				elsif ($indicator =~ /p/i && $hr != 12)  #1-11 PM BECOMES 13-23:
 				{
 					$x =~ s/(\d) (\d\d)/$1 . ' ' . sprintf('%-2.2d',$hr+12)/e;
 				}
 				$x .= $indicator;
 			}
-			eval 
+			eval   #TRY TO CONVERT DATE/TIME STRING TO A PERL/UNIX TIME INTEGER:
 			{
 				$then = &timelocal(substr($x,13,2),substr($x,11,2),substr($x,9,2),
 						substr($x,6,2),(substr($x,4,2)-1),substr($x,0,4),0,0,0);
 			};
 		}		
-		else
+		else   #STRING IS ONLY A DATE, WILL ASSUME MIDNITE (00:00:00) FOR THE TIME PART:
 		{
-			eval 
+			eval   #TRY TO CONVERT DATE STRING TO A PERL/UNIX TIME INTEGER:
 			{
 				$then = &timelocal(0,0,0,substr($x,6,2),
 						(substr($x,4,2)-1),substr($x,0,4),0,0,0);
@@ -1543,17 +1544,17 @@ sub _chkdate#    #CONVER USER-ENTERED DATES TO "yyyymmdd".
 		return wantarray ? ($dt, $then) : $dt;
 	}
 	elsif ($dt =~ s/^(\d\d\d\d\d\d+)(\D+\d+\:?\d+.*)?$/$1/o || $dt =~ s/^(\d{8})(\d{4})/$1/o)
-	{
+	{   #STRING DATE PART HAS NO SEPARATORS:
 		my $timepart = $2 || '';
-		if (length($dt) == 6)   #user entered:  "yymmdd"
+		if (length($dt) == 6)   #2-DIGIT YEAR:  "yymmdd" (2-DIGIT YEAR, MAKE ASSUMPTIONS):
 		{
 			my $century = (substr($dt,0,2) < 80) ? 20 : 19;  #Y2K:80-99=19##; 00-79=20##!
 			$dt = $century . $dt;
 		}
-		else     #user entered:  "mmddyyyy"
+		else   #4-DIGIT YEAR:  "mmddyyyy":
 		{
 			my ($leftpart) = substr($dt,0,4);
-			if ($leftpart < 1300)    #user entered:  "mmddyyyy"
+			if ($leftpart < 1300)    #ASSUME USER MEANT:  "mmddyyyy":
 			{
 				$dt = substr($dt,4,4) . $leftpart;
 			}
@@ -1561,31 +1562,32 @@ sub _chkdate#    #CONVER USER-ENTERED DATES TO "yyyymmdd".
 		my $then = 0;
 		$timepart =~ s/^\D+//o;
 		if ($timepart =~ s#^(\d\d)(\d\d)##o || $timepart =~ s#^(\d\d?)\:(\d\d?)\:?##o)
-		{
+		{   #STRING INCLUDES A "TIME" PART (hhmm[ss] OR hh:mm[:ss]:
 			$dt .= ' ' . sprintf('%-2.2d',$1) . sprintf('%-2.2d',$2);
 			$dt .= ($timepart =~ s#(\d\d?)\s*##o) ? sprintf('%-2.2d',$1) : '00';
-			if ($timepart =~ m#([ap]m?)#io)
+			if ($timepart =~ m#([ap]m?)#io)  #STRING INCLUDES A[M]|P[M], CONVERT AS 12-HOUR TO 24-HOUR:
 			{
 				my $indicator = $1;
 				my $hr = $1  if ($dt =~ /\d (\d\d)/);
-				if ($indicator =~ /a/i && $hr == 12)
+				if ($indicator =~ /a/i && $hr == 12)     #12 AM BECOMES 00:
 				{
 					$dt =~ s/(\d) (\d\d)/$1 . ' 00'/e;
 				}
-				elsif ($indicator =~ /p/i && $hr != 12)
+				elsif ($indicator =~ /p/i && $hr != 12)  #1-11 PM BECOMES 13-23:
 				{
 					$dt =~ s/(\d) (\d\d)/$1 . sprintf('%-2.2d',$hr+12)/e;
 				}
 			}
-			eval 
+			eval   #TRY TO CONVERT DATE/TIME STRING TO A PERL/UNIX TIME INTEGER:
 			{
 				$then = &timelocal(substr($dt,13,2),substr($dt,11,2),substr($dt,9,2),
 						substr($dt,6,2),(substr($dt,4,2)-1),substr($dt,0,4),0,0,0);
 			};
 		}
-		else
+		else   #STRING IS ONLY A DATE, WILL ASSUME MIDNITE (00:00:00) FOR THE TIME PART:
 		{
-			eval {
+			eval   #TRY TO CONVERT DATE STRING TO A PERL/UNIX TIME INTEGER:
+			{
 				$then = &timelocal(0,0,0,substr($dt,6,2),
 						(substr($dt,4,2)-1),substr($dt,0,4),0,0,0);
 			};
